ToGPS

Trait ToGPS 

pub trait ToGPS {
    // Required method
    fn to_gps(&self) -> TimeResult<GPS>;
}
Convert a time scale to GPS Time.

GPS Time runs at the same rate as TAI but with a fixed offset of -19 seconds (GPS = TAI - 19s). It does not include leap seconds, making it continuous since its epoch of January 6, 1980.

Implemented for: GPS (identity), TAI

Required Methods

fn to_gps(&self) -> TimeResult<GPS>

Convert to GPS Time.

Implementors

Source

impl ToGPS for GPS

Identity conversion for GPS.

Source

impl ToGPS for TAI

TAI to GPS conversion. Subtracts 19 seconds.