pub trait ToGPS {
// Required method
fn to_gps(&self) -> TimeResult<GPS>;
}Expand description
Convert a time scale to GPS Time.
GPS Time runs at the same rate as TAI but with a fixed offset of -19 seconds (GPS = TAI - 19s). It does not include leap seconds, making it continuous since its epoch of January 6, 1980.
Implemented for: GPS (identity), TAI
Required Methods
Sourcefn to_gps(&self) -> TimeResult<GPS>
fn to_gps(&self) -> TimeResult<GPS>
Convert to GPS Time.