pub trait ToTCG {
// Required method
fn to_tcg(&self) -> TimeResult<TCG>;
}Expand description
Convert a time scale to Geocentric Coordinate Time (TCG).
TCG is the proper time for a clock at the geocenter, accounting for gravitational time dilation. It runs faster than TT by a rate of approximately 6.969290134e-10 (about 22 ms/year).
Implemented for: TCG (identity), TT
For TCB → TCG, use ToTCGFromTCB.
Required Methods
Sourcefn to_tcg(&self) -> TimeResult<TCG>
fn to_tcg(&self) -> TimeResult<TCG>
Convert to Geocentric Coordinate Time.